@@ -103,6 +103,15 @@ list, rather than to the end."
   :type 'boolean
   :group 'tracking)
 
+(defcustom tracking-sort-faces-first nil
+  "When non-nil, tracked buffers with any highlight face will go to
+the front of the tracking list.
+
+See `tracking-most-recent-first' for whether they are appended at the
+front or the back of the highlighted buffers."
+  :type 'boolean
+  :group 'tracking)
+
 (defcustom tracking-buffer-added-hook nil
   "Hook run when a buffer has some activity.
 
@@ -121,6 +130,14 @@ The functions are run in the context of the buffer."
   :type 'hook
   :group 'tracking)
 
+(defcustom tracking-max-mode-line-entries nil
+  "Maximum number of buffers shown in the mode-line.
+
+If set to nil, all buffers will be shown."
+  :type '(choice (const :tag "All" nil)
+                 (integer :tag "Maximum"))
+  :group 'tracking)
+
 ;;; Internal variables
 (defvar tracking-buffers nil
   "The list of currently tracked buffers.")
@@ -202,7 +219,9 @@ This does check whether BUFFER is currently visible.
 If FACES is given, it lists the faces that might be appropriate
 for BUFFER in the mode line. The highest-priority face of these
 and the current face of the buffer, if any, is used. Priority is
-decided according to `tracking-faces-priorities'."
+decided according to `tracking-faces-priorities'.
+When `tracking-sort-faces-first' is non-nil, all buffers with any
+face set will be stable-sorted before any buffers with no face set."
   (when (and (not (get-buffer-window buffer tracking-frame-behavior))
              (not (tracking-ignored-p buffer faces)))
     (with-current-buffer buffer
@@ -220,6 +239,14 @@ decided according to `tracking-faces-priorities'."
                   (nconc tracking-buffers
                          (list (tracking-faces-merge (buffer-name buffer)
                                                      faces)))))))
+    (when tracking-sort-faces-first
+      (let ((with-any-face (cl-remove-if-not
+                            (lambda (str) (get-text-property 0 'face str))
+                            tracking-buffers))
+            (with-no-face (cl-remove-if
+                           (lambda (str) (get-text-property 0 'face str))
+                           tracking-buffers)))
+        (setq tracking-buffers (nconc with-any-face with-no-face))))
     (setq tracking-mode-line-buffers (tracking-status))
     (force-mode-line-update t)
     ))
@@ -310,31 +337,41 @@ to be ignored."
 (defun tracking-status ()
   "Return the current track status.
 
-This returns a list suitable for `mode-line-format'."
+This returns a list suitable for `mode-line-format'.
+If `tracking-max-mode-line-entries' is a positive integer,
+only return that many entries, ending with '+n'."
   (if (not tracking-buffers)
       ""
     (let* ((buffer-names (cl-remove-if-not #'get-buffer tracking-buffers))
            (shortened-names (tracking-shorten tracking-buffers))
-           (result (list " [")))
-      (while buffer-names
-        (push `(:propertize
-                ,(car shortened-names)
-                face ,(get-text-property 0 'face (car buffer-names))
-                keymap ,(let ((map (make-sparse-keymap)))
-                          (define-key map [mode-line down-mouse-1]
-                            `(lambda ()
-                               (interactive)
-                               (pop-to-buffer ,(car buffer-names))))
-                          map)
-                mouse-face mode-line-highlight
-                help-echo ,(format (concat "New activity in %s\n"
-                                           "mouse-1: pop to the buffer")
-                                   (car buffer-names)))
-              result)
-        (setq buffer-names (cdr buffer-names)
-              shortened-names (cdr shortened-names))
-        (when buffer-names
-          (push "," result)))
+           (result (list " ["))
+           (i 0))
+      (cl-block exit
+        (while buffer-names
+          (push `(:propertize
+                  ,(car shortened-names)
+                  face ,(get-text-property 0 'face (car buffer-names))
+                  keymap ,(let ((map (make-sparse-keymap)))
+                            (define-key map [mode-line down-mouse-1]
+                              `(lambda ()
+                                 (interactive)
+                                 (pop-to-buffer ,(car buffer-names))))
+                            map)
+                  mouse-face mode-line-highlight
+                  help-echo ,(format (concat "New activity in %s\n"
+                                             "mouse-1: pop to the buffer")
+                                     (car buffer-names)))
+                result)
+          (cl-incf i)
+          (setq buffer-names (cdr buffer-names)
+                shortened-names (cdr shortened-names))
+          (when (and tracking-max-mode-line-entries
+                     buffer-names
+                     (>= i tracking-max-mode-line-entries))
+            (push (concat " +" (number-to-string (length buffer-names))) result)
+            (cl-return-from exit))
+          (when buffer-names
+            (push "," result))))
       (push "] " result)
       (nreverse result))))
 
